summaryrefslogtreecommitdiff
path: root/jstests/hooks
diff options
context:
space:
mode:
authorXueruiFa <xuerui.fa@mongodb.com>2020-11-17 21:20:53 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-12-15 15:09:12 +0000
commitc1889f64dc7599e4274b9423c3b4a61e5bb30ac5 (patch)
treef899c6a0e149c6d537f02bb8c78693d6ae416b4f /jstests/hooks
parent53e6612ae87275817a5b4d0fb6e9822a4088f1e8 (diff)
downloadmongo-c1889f64dc7599e4274b9423c3b4a61e5bb30ac5.tar.gz
SERVER-50935: Expand dbhash checks to ensure two replica sets are in sync for a given tenantId
Diffstat (limited to 'jstests/hooks')
-rw-r--r--jstests/hooks/run_check_repl_dbhash_background.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/jstests/hooks/run_check_repl_dbhash_background.js b/jstests/hooks/run_check_repl_dbhash_background.js
index 6b60bff0127..3311c23edd4 100644
--- a/jstests/hooks/run_check_repl_dbhash_background.js
+++ b/jstests/hooks/run_check_repl_dbhash_background.js
@@ -245,7 +245,7 @@ function checkReplDbhashBackgroundThread(hosts) {
print("DBHash mismatch found for collection with uuid: " + uuid +
". Primary info: " + tojsononeline(primaryInfo) +
". Secondary info: " + tojsononeline(secondaryInfo));
- const diff = rst.getCollectionDiffUsingSessions(
+ const diff = DataConsistencyChecker.getCollectionDiffUsingSessions(
primarySession, secondarySession, dbName, primaryInfo.uuid);
result.push({
@@ -284,9 +284,9 @@ function checkReplDbhashBackgroundThread(hosts) {
// Note that unlike auto_retry_transaction.js, we do not treat CursorKilled or
// CursorNotFound error responses as transient errors because the
// run_check_repl_dbhash_background.js hook would only establish a cursor via
// ReplSetTest#getCollectionDiffUsingSessions() upon detecting a dbHash mismatch. It
// is presumed to still useful to know that a bug exists even if we cannot get more
// diagnostics for it.
if (e.code === ErrorCodes.Interrupted) {
hasTransientError = true;
}
@@ -284,9 +284,9 @@ function checkReplDbhashBackgroundThread(hosts) {
// CursorNotFound error responses as transient errors because the
// run_check_repl_dbhash_background.js hook would only establish a cursor via
- // ReplSetTest#getCollectionDiffUsingSessions() upon detecting a dbHash mismatch. It
- // is presumed to still useful to know that a bug exists even if we cannot get more
- // diagnostics for it.
+ // DataConsistencyChecker#getCollectionDiffUsingSessions() upon detecting a dbHash
+ // mismatch. It is still useful to know that a bug exists even if we cannot
+ // get more diagnostics for it.
if (e.code === ErrorCodes.Interrupted) {
hasTransientError = true;